@@ -39,12 +39,12 @@ typedef struct gnutls_pkcs12_bag_int* gnutls_pkcs12_bag;
 int gnutls_pkcs12_init(gnutls_pkcs12 * pkcs12);
 void gnutls_pkcs12_deinit(gnutls_pkcs12 pkcs12);
 int gnutls_pkcs12_import(gnutls_pkcs12 pkcs12, const gnutls_datum * data,
-	gnutls_x509_crt_fmt format, unsigned int flags);
+    gnutls_x509_crt_fmt format, unsigned int flags);
 int gnutls_pkcs12_export( gnutls_pkcs12 pkcs12,
-	gnutls_x509_crt_fmt format, void* output_data, size_t* output_data_size);
+    gnutls_x509_crt_fmt format, void* output_data, size_t* output_data_size);
 
 int gnutls_pkcs12_get_bag(gnutls_pkcs12 pkcs12, 
-	int indx, gnutls_pkcs12_bag bag);
+    int indx, gnutls_pkcs12_bag bag);
 int gnutls_pkcs12_set_bag(gnutls_pkcs12 pkcs12, gnutls_pkcs12_bag bag);
 
 int gnutls_pkcs12_generate_mac(gnutls_pkcs12 pkcs12, const char* pass);
@@ -54,18 +54,18 @@ int gnutls_pkcs12_bag_decrypt(gnutls_pkcs12_bag bag, const char* pass);
 int gnutls_pkcs12_bag_encrypt(gnutls_pkcs12_bag bag, const char* pass, unsigned int flags);
 
 typedef enum gnutls_pkcs12_bag_type {
-	GNUTLS_BAG_EMPTY = 0,
+    GNUTLS_BAG_EMPTY = 0,
 
-	GNUTLS_BAG_PKCS8_ENCRYPTED_KEY=1,
-	GNUTLS_BAG_PKCS8_KEY,
-	GNUTLS_BAG_CERTIFICATE,
-	GNUTLS_BAG_CRL,
-	GNUTLS_BAG_ENCRYPTED=10,
-	GNUTLS_BAG_UNKNOWN=20
+    GNUTLS_BAG_PKCS8_ENCRYPTED_KEY=1,
+    GNUTLS_BAG_PKCS8_KEY,
+    GNUTLS_BAG_CERTIFICATE,
+    GNUTLS_BAG_CRL,
+    GNUTLS_BAG_ENCRYPTED=10,
+    GNUTLS_BAG_UNKNOWN=20
 } gnutls_pkcs12_bag_type;
 
 gnutls_pkcs12_bag_type gnutls_pkcs12_bag_get_type(gnutls_pkcs12_bag bag, int indx);
-int gnutls_pkcs12_bag_get_data(gnutls_pkcs12_bag bag, int indx, gnutls_const_datum* data);
+int gnutls_pkcs12_bag_get_data(gnutls_pkcs12_bag bag, int indx, gnutls_datum* data);
 int gnutls_pkcs12_bag_set_data(gnutls_pkcs12_bag bag, gnutls_pkcs12_bag_type type,
         const gnutls_datum* data);
 int gnutls_pkcs12_bag_set_crl(gnutls_pkcs12_bag bag, gnutls_x509_crl crl);
@@ -76,14 +76,14 @@ void gnutls_pkcs12_bag_deinit(gnutls_pkcs12_bag bag);
 int gnutls_pkcs12_bag_get_count(gnutls_pkcs12_bag bag);
 
 int gnutls_pkcs12_bag_get_key_id(gnutls_pkcs12_bag bag, int indx, 
-	gnutls_datum* id);
+    gnutls_datum* id);
 int gnutls_pkcs12_bag_set_key_id(gnutls_pkcs12_bag bag, int indx, 
-	const gnutls_datum* id);
+    const gnutls_datum* id);
 
 int gnutls_pkcs12_bag_get_friendly_name(gnutls_pkcs12_bag bag, int indx, 
-	char **name);
+    char **name);
 int gnutls_pkcs12_bag_set_friendly_name(gnutls_pkcs12_bag bag, int indx, 
-	const char* name);
+    const char* name);
 
 #ifdef __cplusplus
 }
