@@ -40,9 +40,40 @@ static const int anon_dummy;
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to free (deallocate) it.
   **/
-void gnutls_anon_free_server_credentials( gnutls_anon_server_credentials sc) {
+void gnutls_anon_free_server_credentials(gnutls_anon_server_credentials sc)
+{
 
-	gnutls_free( sc);
+    gnutls_free(sc);
+}
+
+/*-
+  * _gnutls_anon_get_dh_params - Returns the DH parameters pointer
+  * @sc: is an &gnutls_certificate_credentials structure.
+  *
+  * This function will return the dh parameters pointer.
+  *
+  -*/
+gnutls_dh_params _gnutls_anon_get_dh_params(const
+					    gnutls_anon_server_credentials
+					    sc, gnutls_session session)
+{
+    gnutls_params_st params;
+    int ret;
+
+    if (session->internals.params.anon_dh_params)
+	return session->internals.params.anon_dh_params;
+
+    if (sc->dh_params) {
+	session->internals.params.anon_dh_params = sc->dh_params;
+    } else if (sc->params_func) {
+	ret = sc->params_func(session, GNUTLS_PARAMS_DH, &params);
+	if (ret == 0 && params.type == GNUTLS_PARAMS_DH) {
+	    session->internals.params.anon_dh_params = params.params.dh;
+	    session->internals.params.free_anon_dh_params = params.deinit;
+	}
+    }
+
+    return session->internals.params.anon_dh_params;
 }
 
 /**
@@ -52,11 +83,13 @@ void gnutls_anon_free_server_credentials( gnutls_anon_server_credentials sc) {
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to allocate it.
   **/
-int gnutls_anon_allocate_server_credentials( gnutls_anon_server_credentials *sc) {
+int gnutls_anon_allocate_server_credentials(gnutls_anon_server_credentials
+					    * sc)
+{
 
-	*sc = gnutls_calloc( 1, sizeof(ANON_SERVER_CREDENTIALS_INT));
+    *sc = gnutls_calloc(1, sizeof(anon_server_credentials_st));
 
-	return 0;
+    return 0;
 }
 
 
@@ -67,24 +100,26 @@ int gnutls_anon_allocate_server_credentials( gnutls_anon_server_credentials *sc)
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to free (deallocate) it.
   **/
-void gnutls_anon_free_client_credentials( gnutls_anon_client_credentials sc) {
+void gnutls_anon_free_client_credentials(gnutls_anon_client_credentials sc)
+{
 }
 
 /**
-  * gnutls_allocate_anon_client_credentials - Used to allocate an GNUTLS_ANON_CLIENT CREDENTIALS structure
+  * gnutls_allocate_anon_client_credentials - Used to allocate a credentials structure
   * @sc: is a pointer to an &gnutls_anon_client_credentials structure.
   *
   * This structure is complex enough to manipulate directly thus
   * this helper function is provided in order to allocate it.
   **/
-int gnutls_anon_allocate_client_credentials( gnutls_anon_client_credentials *sc) 
+int gnutls_anon_allocate_client_credentials(gnutls_anon_client_credentials
+					    * sc)
 {
-	/* anon_dummy is only there for *sc not to be null.
-	 * it is not used at all;
-	 */
-	*sc = (void*) &anon_dummy;
-	
-	return 0;
+    /* anon_dummy is only there for *sc not to be null.
+     * it is not used at all;
+     */
+    *sc = (void *) &anon_dummy;
+
+    return 0;
 }
 
 #endif
