@@ -21,13 +21,15 @@
 #ifndef GNUTLS_CIPHER_INT
 # define GNUTLS_CIPHER_INT
 
-#define GNUTLS_CIPHER_HANDLE GCRY_CIPHER_HD
+#define cipher_hd_t gcry_cipher_hd_t
 #define GNUTLS_CIPHER_FAILED NULL
 
-GNUTLS_CIPHER_HANDLE _gnutls_cipher_init( gnutls_cipher_algorithm cipher, 
-	const gnutls_datum *key, const gnutls_datum *iv);
-int _gnutls_cipher_encrypt(GNUTLS_CIPHER_HANDLE handle, void* text, int textlen);
-int _gnutls_cipher_decrypt(GNUTLS_CIPHER_HANDLE handle, void* ciphertext, int ciphertextlen);
-void _gnutls_cipher_deinit(GNUTLS_CIPHER_HANDLE handle);
+cipher_hd_t _gnutls_cipher_init(gnutls_cipher_algorithm cipher,
+				const gnutls_datum * key,
+				const gnutls_datum * iv);
+int _gnutls_cipher_encrypt(cipher_hd_t handle, void *text, int textlen);
+int _gnutls_cipher_decrypt(cipher_hd_t handle, void *ciphertext,
+			   int ciphertextlen);
+void _gnutls_cipher_deinit(cipher_hd_t handle);
 
-#endif /* GNUTLS_CIPHER_INT */
+#endif				/* GNUTLS_CIPHER_INT */
