@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2001,2002,2003 Nikos Mavroyanopoulos
+ * Copyright (C) 2004 Free Software Foundation
  *
  * This file is part of GNUTLS.
  *
@@ -30,6 +31,7 @@
 #include <gnutls_errors.h>
 #include <gnutls_auth_int.h>
 #include <gnutls_state.h>
+#include <gnutls_datum.h>
 
 /* ANON & DHE */
 
@@ -51,44 +53,153 @@
   **/
 void gnutls_dh_set_prime_bits(gnutls_session session, unsigned int bits)
 {
-	session->internals.dh_prime_bits = bits;
+    session->internals.dh_prime_bits = bits;
 }
 
+
 /**
-  * gnutls_dh_get_prime_bits - This function returns the bits used in DH authentication
+  * gnutls_dh_get_group - This function returns the group of the DH authentication
   * @session: is a gnutls session
+  * @raw_gen: will hold the generator.
+  * @raw_prime: will hold the prime.
+  *
+  * This function will return the group parameters used in the last Diffie Hellman 
+  * authentication with the peer. These are the prime and the generator used.
+  * This function should be used for both anonymous and ephemeral diffie Hellman.
+  * The output parameters must be freed with gnutls_free().
   *
-  * This function will return the bits of the prime used in the last Diffie Hellman authentication
-  * with the peer. Should be used for both anonymous and ephemeral diffie Hellman.
   * Returns a negative value in case of an error.
   *
   **/
-int gnutls_dh_get_prime_bits(gnutls_session session)
+int gnutls_dh_get_group(gnutls_session session,
+			gnutls_datum * raw_gen, gnutls_datum * raw_prime)
 {
-	switch( gnutls_auth_get_type( session)) {
-		case GNUTLS_CRD_ANON: {
-			ANON_SERVER_AUTH_INFO info;
+    dh_info_t *dh;
+    int ret;
+    anon_server_auth_info_t anon_info;
+    cert_auth_info_t cert_info;
 
-			info = _gnutls_get_auth_info(session);
-			if (info == NULL)
-				return GNUTLS_E_INTERNAL_ERROR;
-			return info->dh_prime_bits;
-		}
-		case GNUTLS_CRD_CERTIFICATE: {
-			CERTIFICATE_AUTH_INFO info;
+    switch (gnutls_auth_get_type(session)) {
+    case GNUTLS_CRD_ANON:
+	anon_info = _gnutls_get_auth_info(session);
+	if (anon_info == NULL)
+	    return GNUTLS_E_INTERNAL_ERROR;
+	dh = &anon_info->dh;
+	break;
+    case GNUTLS_CRD_CERTIFICATE:
+	cert_info = _gnutls_get_auth_info(session);
+	if (cert_info == NULL)
+	    return GNUTLS_E_INTERNAL_ERROR;
+	dh = &cert_info->dh;
+	break;
+    default:
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-			info = _gnutls_get_auth_info(session);
-			if (info == NULL)
-				return GNUTLS_E_INTERNAL_ERROR;
+    ret = _gnutls_set_datum(raw_prime, dh->prime, dh->prime_size);
+    if (ret < 0) {
+	gnutls_assert();
+	return ret;
+    }
 
-			return info->dh_prime_bits;
-		}
-		default:
-			gnutls_assert();
-			return GNUTLS_E_INVALID_REQUEST;
-	}
+    ret = _gnutls_set_datum(raw_gen, dh->generator, dh->generator_size);
+    if (ret < 0) {
+	gnutls_assert();
+	_gnutls_free_datum(raw_prime);
+	return ret;
+    }
+
+    return 0;
 }
 
+/**
+  * gnutls_dh_get_pubkey - This function returns the peer's public key used in DH authentication
+  * @session: is a gnutls session
+  * @raw_key: will hold the public key.
+  *
+  * This function will return the peer's public key used in the last Diffie Hellman authentication.
+  * This function should be used for both anonymous and ephemeral diffie Hellman.
+  * The output parameters must be freed with gnutls_free().
+  *
+  * Returns a negative value in case of an error.
+  *
+  **/
+int gnutls_dh_get_pubkey(gnutls_session session, gnutls_datum * raw_key)
+{
+    dh_info_t *dh;
+    anon_server_auth_info_t anon_info;
+    cert_auth_info_t cert_info;
+
+    switch (gnutls_auth_get_type(session)) {
+    case GNUTLS_CRD_ANON:{
+	    anon_info = _gnutls_get_auth_info(session);
+	    if (anon_info == NULL)
+		return GNUTLS_E_INTERNAL_ERROR;
+	    dh = &anon_info->dh;
+	    break;
+	}
+    case GNUTLS_CRD_CERTIFICATE:{
+
+	    cert_info = _gnutls_get_auth_info(session);
+	    if (cert_info == NULL)
+		return GNUTLS_E_INTERNAL_ERROR;
+	    dh = &cert_info->dh;
+	    break;
+	}
+    default:
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
+
+    return _gnutls_set_datum(raw_key, dh->public_key, dh->public_key_size);
+}
+
+/**
+  * gnutls_rsa_export_get_modulus - This function returns the peer's modulus used in RSA-EXPORT authentication
+  * @session: is a gnutls session
+  * @exp: will hold the exponent.
+  * @mod: will hold the modulus.
+  *
+  * This function will return the peer's modulus used in the last RSA-EXPORT authentication.
+  * The output parameters must be freed with gnutls_free().
+  *
+  * Returns a negative value in case of an error.
+  *
+  **/
+int gnutls_rsa_export_get_pubkey(gnutls_session session,
+				 gnutls_datum * exp, gnutls_datum * mod)
+{
+    cert_auth_info_t info;
+    int ret;
+
+    if (gnutls_auth_get_type(session) == GNUTLS_CRD_CERTIFICATE) {
+	info = _gnutls_get_auth_info(session);
+	if (info == NULL)
+	    return GNUTLS_E_INTERNAL_ERROR;
+
+	ret = _gnutls_set_datum(mod, info->rsa_export.modulus,
+				info->rsa_export.modulus_size);
+	if (ret < 0) {
+	    gnutls_assert();
+	    return ret;
+	}
+
+	ret = _gnutls_set_datum(exp, info->rsa_export.exponent,
+				info->rsa_export.exponent_size);
+	if (ret < 0) {
+	    gnutls_assert();
+	    _gnutls_free_datum(mod);
+	    return ret;
+	}
+
+	return 0;
+    }
+
+    return GNUTLS_E_INVALID_REQUEST;
+}
+
+
 /**
   * gnutls_dh_get_secret_bits - This function returns the bits used in DH authentication
   * @session: is a gnutls session
@@ -100,31 +211,73 @@ int gnutls_dh_get_prime_bits(gnutls_session session)
   **/
 int gnutls_dh_get_secret_bits(gnutls_session session)
 {
-	switch( gnutls_auth_get_type( session)) {
-		case GNUTLS_CRD_ANON: {
-			ANON_SERVER_AUTH_INFO info;
+    switch (gnutls_auth_get_type(session)) {
+    case GNUTLS_CRD_ANON:{
+	    anon_server_auth_info_t info;
 
-			info = _gnutls_get_auth_info(session);
-			if (info == NULL)
-				return GNUTLS_E_INTERNAL_ERROR;
-			return info->dh_secret_bits;
-		}
-		case GNUTLS_CRD_CERTIFICATE: {
-			CERTIFICATE_AUTH_INFO info;
-
-			info = _gnutls_get_auth_info(session);
-			if (info == NULL)
-				return GNUTLS_E_INTERNAL_ERROR;
-
-			return info->dh_secret_bits;
-		}
-		default:
-			gnutls_assert();
-			return GNUTLS_E_INVALID_REQUEST;
+	    info = _gnutls_get_auth_info(session);
+	    if (info == NULL)
+		return GNUTLS_E_INTERNAL_ERROR;
+	    return info->dh.secret_bits;
 	}
+    case GNUTLS_CRD_CERTIFICATE:{
+	    cert_auth_info_t info;
+
+	    info = _gnutls_get_auth_info(session);
+	    if (info == NULL)
+		return GNUTLS_E_INTERNAL_ERROR;
+
+	    return info->dh.secret_bits;
+	}
+    default:
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 }
 
 
+/**
+  * gnutls_dh_get_prime_bits - This function returns the bits used in DH authentication
+  * @session: is a gnutls session
+  *
+  * This function will return the bits of the prime used in the last Diffie Hellman authentication
+  * with the peer. Should be used for both anonymous and ephemeral diffie Hellman.
+  * Returns a negative value in case of an error.
+  *
+  **/
+int gnutls_dh_get_prime_bits(gnutls_session session)
+{
+    dh_info_t *dh;
+
+    switch (gnutls_auth_get_type(session)) {
+    case GNUTLS_CRD_ANON:{
+	    anon_server_auth_info_t info;
+
+	    info = _gnutls_get_auth_info(session);
+	    if (info == NULL)
+		return GNUTLS_E_INTERNAL_ERROR;
+	    dh = &info->dh;
+	    break;
+	}
+    case GNUTLS_CRD_CERTIFICATE:{
+	    cert_auth_info_t info;
+
+	    info = _gnutls_get_auth_info(session);
+	    if (info == NULL)
+		return GNUTLS_E_INTERNAL_ERROR;
+
+	    dh = &info->dh;
+	    break;
+	}
+    default:
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
+
+    return (dh->prime_size) * 8;
+
+}
+
 /**
   * gnutls_rsa_export_get_modulus_bits - This function returns the bits used in RSA-export key exchange
   * @session: is a gnutls session
@@ -136,13 +289,13 @@ int gnutls_dh_get_secret_bits(gnutls_session session)
   **/
 int gnutls_rsa_export_get_modulus_bits(gnutls_session session)
 {
-CERTIFICATE_AUTH_INFO info;
+    cert_auth_info_t info;
 
-	info = _gnutls_get_auth_info(session);
-	if (info == NULL)
-		return GNUTLS_E_INTERNAL_ERROR;
+    info = _gnutls_get_auth_info(session);
+    if (info == NULL)
+	return GNUTLS_E_INTERNAL_ERROR;
 
-	return info->rsa_export_modulus_bits;
+    return info->rsa_export.modulus_size * 8;
 }
 
 /**
@@ -156,28 +309,36 @@ CERTIFICATE_AUTH_INFO info;
   **/
 int gnutls_dh_get_peers_public_bits(gnutls_session session)
 {
-	switch( gnutls_auth_get_type( session)) {
-		case GNUTLS_CRD_ANON: {
-			ANON_SERVER_AUTH_INFO info;
+    dh_info_t *dh;
 
-			info = _gnutls_get_auth_info(session);
-			if (info == NULL)
-				return GNUTLS_E_INTERNAL_ERROR;
-			return info->dh_peer_public_bits;
-		}
-		case GNUTLS_CRD_CERTIFICATE: {
-			CERTIFICATE_AUTH_INFO info;
+    switch (gnutls_auth_get_type(session)) {
+    case GNUTLS_CRD_ANON:{
+	    anon_server_auth_info_t info;
 
-			info = _gnutls_get_auth_info(session);
-			if (info == NULL)
-				return GNUTLS_E_INTERNAL_ERROR;
+	    info = _gnutls_get_auth_info(session);
+	    if (info == NULL)
+		return GNUTLS_E_INTERNAL_ERROR;
 
-			return info->dh_peer_public_bits;
-		}
-		default:
-			gnutls_assert();
-			return GNUTLS_E_INVALID_REQUEST;
+	    dh = &info->dh;
+	    break;
 	}
+    case GNUTLS_CRD_CERTIFICATE:{
+	    cert_auth_info_t info;
+
+	    info = _gnutls_get_auth_info(session);
+	    if (info == NULL)
+		return GNUTLS_E_INTERNAL_ERROR;
+
+	    dh = &info->dh;
+	    break;
+	}
+    default:
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
+
+    return dh->public_key_size * 8;
+
 }
 
 /* CERTIFICATE STUFF */
@@ -195,20 +356,20 @@ int gnutls_dh_get_peers_public_bits(gnutls_session session)
   **/
 const gnutls_datum *gnutls_certificate_get_ours(gnutls_session session)
 {
-	const gnutls_certificate_credentials cred;
+    const gnutls_certificate_credentials cred;
 
-	CHECK_AUTH(GNUTLS_CRD_CERTIFICATE, NULL);
+    CHECK_AUTH(GNUTLS_CRD_CERTIFICATE, NULL);
 
-	cred = _gnutls_get_cred(session->key, GNUTLS_CRD_CERTIFICATE, NULL);
-	if (cred == NULL || cred->cert_list == NULL) {
-		gnutls_assert();
-		return NULL;
-	}
+    cred = _gnutls_get_cred(session->key, GNUTLS_CRD_CERTIFICATE, NULL);
+    if (cred == NULL || cred->cert_list == NULL) {
+	gnutls_assert();
+	return NULL;
+    }
 
-	if (session->internals.selected_cert_list == NULL)
-		return NULL;
+    if (session->internals.selected_cert_list == NULL)
+	return NULL;
 
-	return &session->internals.selected_cert_list[0].raw;
+    return &session->internals.selected_cert_list[0].raw;
 }
 
 /**
@@ -225,19 +386,19 @@ const gnutls_datum *gnutls_certificate_get_ours(gnutls_session session)
   * Returns NULL in case of an error, or if no certificate was sent.
   *
   **/
-const gnutls_datum *gnutls_certificate_get_peers(gnutls_session session, 
-	unsigned int *list_size)
+const gnutls_datum *gnutls_certificate_get_peers(gnutls_session session,
+						 unsigned int *list_size)
 {
-	CERTIFICATE_AUTH_INFO info;
+    cert_auth_info_t info;
 
-	CHECK_AUTH(GNUTLS_CRD_CERTIFICATE, NULL);
+    CHECK_AUTH(GNUTLS_CRD_CERTIFICATE, NULL);
 
-	info = _gnutls_get_auth_info(session);
-	if (info == NULL)
-		return NULL;
+    info = _gnutls_get_auth_info(session);
+    if (info == NULL)
+	return NULL;
 
-	*list_size = info->ncerts;
-	return info->raw_certificate_list;
+    *list_size = info->ncerts;
+    return info->raw_certificate_list;
 }
 
 
@@ -252,14 +413,14 @@ const gnutls_datum *gnutls_certificate_get_peers(gnutls_session session,
   **/
 int gnutls_certificate_client_get_request_status(gnutls_session session)
 {
-	CERTIFICATE_AUTH_INFO info;
+    cert_auth_info_t info;
 
-	CHECK_AUTH(GNUTLS_CRD_CERTIFICATE, 0);
+    CHECK_AUTH(GNUTLS_CRD_CERTIFICATE, 0);
 
-	info = _gnutls_get_auth_info(session);
-	if (info == NULL)
-		return GNUTLS_E_INTERNAL_ERROR;
-	return info->certificate_requested;
+    info = _gnutls_get_auth_info(session);
+    if (info == NULL)
+	return GNUTLS_E_INTERNAL_ERROR;
+    return info->certificate_requested;
 }
 
 /**
@@ -282,30 +443,30 @@ int gnutls_certificate_client_get_request_status(gnutls_session session)
   * Returns a negative value in case of an error.
   *
   **/
-int gnutls_fingerprint(gnutls_digest_algorithm algo, const gnutls_datum* data, 
-	void* result, size_t* result_size)
+int gnutls_fingerprint(gnutls_digest_algorithm algo,
+		       const gnutls_datum * data, void *result,
+		       size_t * result_size)
 {
-	GNUTLS_HASH_HANDLE td;
-	int hash_len = _gnutls_hash_get_algo_len(algo);
-	
-	if (hash_len < 0 || (uint)hash_len > *result_size ||
-		result==NULL) 
-	{
-		*result_size = hash_len;
-		return GNUTLS_E_SHORT_MEMORY_BUFFER;
-	}
-	*result_size = hash_len;
+    GNUTLS_HASH_HANDLE td;
+    int hash_len = _gnutls_hash_get_algo_len(algo);
 
-	if (result) {
-		td = _gnutls_hash_init( algo);
-		if (td==NULL) return GNUTLS_E_HASH_FAILED;
-	
-		_gnutls_hash( td, data->data, data->size);
-	
-		_gnutls_hash_deinit( td, result);
-	}
-		
-	return 0;
+    if (hash_len < 0 || (uint) hash_len > *result_size || result == NULL) {
+	*result_size = hash_len;
+	return GNUTLS_E_SHORT_MEMORY_BUFFER;
+    }
+    *result_size = hash_len;
+
+    if (result) {
+	td = _gnutls_hash_init(algo);
+	if (td == NULL)
+	    return GNUTLS_E_HASH_FAILED;
+
+	_gnutls_hash(td, data->data, data->size);
+
+	_gnutls_hash_deinit(td, result);
+    }
+
+    return 0;
 }
 
 /**
@@ -318,8 +479,10 @@ int gnutls_fingerprint(gnutls_digest_algorithm algo, const gnutls_datum* data,
   * cipher suites.
   *
   **/
-void gnutls_anon_set_server_dh_params( gnutls_anon_server_credentials res, gnutls_dh_params dh_params) {
-	res->dh_params = dh_params;
+void gnutls_anon_set_server_dh_params(gnutls_anon_server_credentials res,
+				      gnutls_dh_params dh_params)
+{
+    res->dh_params = dh_params;
 }
 
 /**
@@ -332,10 +495,46 @@ void gnutls_anon_set_server_dh_params( gnutls_anon_server_credentials res, gnutl
   * cipher suites.
   *
   **/
-void gnutls_certificate_set_dh_params(gnutls_certificate_credentials res, gnutls_dh_params dh_params) {
-	res->dh_params = dh_params;
+void gnutls_certificate_set_dh_params(gnutls_certificate_credentials res,
+				      gnutls_dh_params dh_params)
+{
+    res->dh_params = dh_params;
 }
 
+/**
+  * gnutls_certificate_set_params_function - This function will set the DH or RSA parameters callback
+  * @res: is a gnutls_certificate_credentials structure
+  * @func: is the function to be called
+  *
+  * This function will set a callback in order for the server to get the 
+  * diffie hellman or RSA parameters for certificate authentication. The callback
+  * should return zero on success.
+  *
+  **/
+void gnutls_certificate_set_params_function(gnutls_certificate_credentials
+					    res,
+					    gnutls_params_function * func)
+{
+    res->params_func = func;
+}
+
+/**
+  * gnutls_anon_set_params_function - This function will set the DH parameters callback
+  * @res: is a gnutls_certificate_credentials structure
+  * @func: is the function to be called
+  *
+  * This function will set a callback in order for the server to get the 
+  * diffie hellman parameters for anonymous authentication. The callback should
+  * return zero on success.
+  *
+  **/
+void gnutls_anon_set_params_function(gnutls_anon_server_credentials res,
+				     gnutls_params_function * func)
+{
+    res->params_func = func;
+}
+
+
 /**
   * gnutls_certificate_set_verify_flags - This function will set the flags to be used at certificate verification
   * @res: is a gnutls_certificate_credentials structure
@@ -345,9 +544,10 @@ void gnutls_certificate_set_dh_params(gnutls_certificate_credentials res, gnutls
   * Flags must be OR of the gnutls_certificate_verify_flags enumerations.
   *
   **/
-void gnutls_certificate_set_verify_flags(gnutls_certificate_credentials res, unsigned int flags) 
+void gnutls_certificate_set_verify_flags(gnutls_certificate_credentials
+					 res, unsigned int flags)
 {
-	res->verify_flags = flags;
+    res->verify_flags = flags;
 }
 
 /**
@@ -360,7 +560,9 @@ void gnutls_certificate_set_verify_flags(gnutls_certificate_credentials res, uns
   * cipher suites.
   *
   **/
-void gnutls_certificate_set_rsa_export_params(gnutls_certificate_credentials res, gnutls_rsa_params rsa_params) 
+void
+gnutls_certificate_set_rsa_export_params(gnutls_certificate_credentials
+					 res, gnutls_rsa_params rsa_params)
 {
-	res->rsa_params = rsa_params;
+    res->rsa_params = rsa_params;
 }
