@@ -48,19 +48,20 @@
   **/
 int gnutls_x509_crl_init(gnutls_x509_crl * crl)
 {
-	*crl = gnutls_calloc(1, sizeof(gnutls_x509_crl_int));
+    *crl = gnutls_calloc(1, sizeof(gnutls_x509_crl_int));
 
-	if (*crl) {
-		int result = asn1_create_element(_gnutls_get_pkix(),
-				     "PKIX1.CertificateList",
-				     &(*crl)->crl);
-		if (result != ASN1_SUCCESS) {
-			gnutls_assert();
-			return _gnutls_asn2err(result);
-		}
-		return 0;	/* success */
+    if (*crl) {
+	int result = asn1_create_element(_gnutls_get_pkix(),
+					 "PKIX1.CertificateList",
+					 &(*crl)->crl);
+	if (result != ASN1_SUCCESS) {
+	    gnutls_assert();
+	    gnutls_free(*crl);
+	    return _gnutls_asn2err(result);
 	}
-	return GNUTLS_E_MEMORY_ERROR;
+	return 0;		/* success */
+    }
+    return GNUTLS_E_MEMORY_ERROR;
 }
 
 /**
@@ -72,12 +73,13 @@ int gnutls_x509_crl_init(gnutls_x509_crl * crl)
   **/
 void gnutls_x509_crl_deinit(gnutls_x509_crl crl)
 {
-	if (!crl) return;
+    if (!crl)
+	return;
 
-	if (crl->crl)
-		asn1_delete_structure(&crl->crl);
+    if (crl->crl)
+	asn1_delete_structure(&crl->crl);
 
-	gnutls_free(crl);
+    gnutls_free(crl);
 }
 
 /**
@@ -97,57 +99,55 @@ void gnutls_x509_crl_deinit(gnutls_x509_crl crl)
 int gnutls_x509_crl_import(gnutls_x509_crl crl, const gnutls_datum * data,
 			   gnutls_x509_crt_fmt format)
 {
-	int result = 0, need_free = 0;
-	gnutls_datum _data;
-	
-	_data.data = data->data;
-	_data.size = data->size;
+    int result = 0, need_free = 0;
+    gnutls_datum _data;
 
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    _data.data = data->data;
+    _data.size = data->size;
 
-	/* If the CRL is in PEM format then decode it
-	 */
-	if (format == GNUTLS_X509_FMT_PEM) {
-		opaque *out;
-
-		result =
-		    _gnutls_fbase64_decode(PEM_CRL, data->data, data->size,
-					   &out);
-
-		if (result <= 0) {
-			if (result == 0)
-				result = GNUTLS_E_INTERNAL_ERROR;
-			gnutls_assert();
-			return result;
-		}
-
-		_data.data = out;
-		_data.size = result;
-
-		need_free = 1;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
+    /* If the CRL is in PEM format then decode it
+     */
+    if (format == GNUTLS_X509_FMT_PEM) {
+	opaque *out;
 
 	result =
-	    asn1_der_decoding(&crl->crl, _data.data, _data.size, NULL);
-	if (result != ASN1_SUCCESS) {
-		result = _gnutls_asn2err(result);
-		gnutls_assert();
-		goto cleanup;
+	    _gnutls_fbase64_decode(PEM_CRL, data->data, data->size, &out);
+
+	if (result <= 0) {
+	    if (result == 0)
+		result = GNUTLS_E_INTERNAL_ERROR;
+	    gnutls_assert();
+	    return result;
 	}
 
-	if (need_free)
-		_gnutls_free_datum(&_data);
+	_data.data = out;
+	_data.size = result;
 
-	return 0;
+	need_free = 1;
+    }
 
-      cleanup:
-	if (need_free)
-		_gnutls_free_datum(&_data);
-	return result;
+
+    result = asn1_der_decoding(&crl->crl, _data.data, _data.size, NULL);
+    if (result != ASN1_SUCCESS) {
+	result = _gnutls_asn2err(result);
+	gnutls_assert();
+	goto cleanup;
+    }
+
+    if (need_free)
+	_gnutls_free_datum(&_data);
+
+    return 0;
+
+  cleanup:
+    if (need_free)
+	_gnutls_free_datum(&_data);
+    return result;
 }
 
 
@@ -155,7 +155,7 @@ int gnutls_x509_crl_import(gnutls_x509_crl crl, const gnutls_datum * data,
   * gnutls_x509_crl_get_issuer_dn - This function returns the CRL's issuer distinguished name
   * @crl: should contain a gnutls_x509_crl structure
   * @buf: a pointer to a structure to hold the peer's name (may be null)
-  * @sizeof_buf: initialy holds the size of 'buf'
+  * @sizeof_buf: initially holds the size of @buf
   *
   * This function will copy the name of the CRL issuer in the provided buffer. The name 
   * will be in the form "C=xxxx,O=yyyy,CN=zzzz" as described in RFC2253. The output
@@ -169,16 +169,16 @@ int gnutls_x509_crl_import(gnutls_x509_crl crl, const gnutls_datum * data,
   *
   **/
 int gnutls_x509_crl_get_issuer_dn(gnutls_x509_crl crl, char *buf,
-				  size_t *sizeof_buf)
+				  size_t * sizeof_buf)
 {
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	return _gnutls_x509_parse_dn(crl->crl,
-				     "tbsCertList.issuer.rdnSequence",
-				     buf, sizeof_buf);
+    return _gnutls_x509_parse_dn(crl->crl,
+				 "tbsCertList.issuer.rdnSequence",
+				 buf, sizeof_buf);
 }
 
 /**
@@ -188,7 +188,7 @@ int gnutls_x509_crl_get_issuer_dn(gnutls_x509_crl crl, char *buf,
   * @indx: In case multiple same OIDs exist in the RDN, this specifies which to send. Use zero to get the first one.
   * @raw_flag: If non zero returns the raw DER data of the DN part.
   * @buf: a pointer to a structure to hold the peer's name (may be null)
-  * @sizeof_buf: initialy holds the size of 'buf'
+  * @sizeof_buf: initially holds the size of @buf
   *
   * This function will extract the part of the name of the CRL issuer specified
   * by the given OID. The output will be encoded as described in RFC2253. The output
@@ -207,17 +207,18 @@ int gnutls_x509_crl_get_issuer_dn(gnutls_x509_crl crl, char *buf,
   *
   **/
 int gnutls_x509_crl_get_issuer_dn_by_oid(gnutls_x509_crl crl,
-	const char *oid, int indx, unsigned int raw_flag,
-	void *buf, size_t *sizeof_buf)
+					 const char *oid, int indx,
+					 unsigned int raw_flag, void *buf,
+					 size_t * sizeof_buf)
 {
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	return _gnutls_x509_parse_dn_oid(crl->crl,
-					 "tbsCertList.issuer.rdnSequence",
-					 oid, indx, raw_flag, buf, sizeof_buf);
+    return _gnutls_x509_parse_dn_oid(crl->crl,
+				     "tbsCertList.issuer.rdnSequence",
+				     oid, indx, raw_flag, buf, sizeof_buf);
 }
 
 /**
@@ -225,7 +226,7 @@ int gnutls_x509_crl_get_issuer_dn_by_oid(gnutls_x509_crl crl,
   * @crl: should contain a gnutls_x509_crl structure
   * @indx: Specifies which DN OID to send. Use zero to get the first one.
   * @oid: a pointer to a structure to hold the name (may be null)
-  * @sizeof_oid: initialy holds the size of 'oid'
+  * @sizeof_oid: initially holds the size of 'oid'
   *
   * This function will extract the requested OID of the name of the CRL issuer, specified
   * by the given index. 
@@ -237,16 +238,17 @@ int gnutls_x509_crl_get_issuer_dn_by_oid(gnutls_x509_crl crl,
   * On success 0 is returned.
   *
   **/
-int gnutls_x509_crl_get_dn_oid(gnutls_x509_crl crl, 
-	int indx, void *oid, size_t *sizeof_oid)
+int gnutls_x509_crl_get_dn_oid(gnutls_x509_crl crl,
+			       int indx, void *oid, size_t * sizeof_oid)
 {
-	if (crl==NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	return _gnutls_x509_get_dn_oid( crl->crl, 
-		 "tbsCertList.issuer.rdnSequence", indx, oid, sizeof_oid);
+    return _gnutls_x509_get_dn_oid(crl->crl,
+				   "tbsCertList.issuer.rdnSequence", indx,
+				   oid, sizeof_oid);
 }
 
 
@@ -262,30 +264,32 @@ int gnutls_x509_crl_get_dn_oid(gnutls_x509_crl crl,
   **/
 int gnutls_x509_crl_get_signature_algorithm(gnutls_x509_crl crl)
 {
-	int result;
-	gnutls_datum sa;
+    int result;
+    gnutls_datum sa;
 
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	/* Read the signature algorithm. Note that parameters are not
-	 * read. They will be read from the issuer's certificate if needed.
-	 */
-		
-	result = _gnutls_x509_read_value( crl->crl, "signatureAlgorithm.algorithm", &sa, 0);
-		
-	if (result < 0) {
-		gnutls_assert();
-		return result;
-	}
-	
-	result = _gnutls_x509_oid2sign_algorithm( (const char*)sa.data);
+    /* Read the signature algorithm. Note that parameters are not
+     * read. They will be read from the issuer's certificate if needed.
+     */
 
-	_gnutls_free_datum( &sa);
+    result =
+	_gnutls_x509_read_value(crl->crl, "signatureAlgorithm.algorithm",
+				&sa, 0);
 
+    if (result < 0) {
+	gnutls_assert();
 	return result;
+    }
+
+    result = _gnutls_x509_oid2sign_algorithm((const char *) sa.data);
+
+    _gnutls_free_datum(&sa);
+
+    return result;
 }
 
 /**
@@ -299,23 +303,23 @@ int gnutls_x509_crl_get_signature_algorithm(gnutls_x509_crl crl)
   **/
 int gnutls_x509_crl_get_version(gnutls_x509_crl crl)
 {
-	opaque version[5];
-	int len, result;
+    opaque version[5];
+    int len, result;
 
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	len = sizeof(version);
-	if ((result =
-	     asn1_read_value(crl->crl, "tbsCertList.version", version,
-			     &len)) != ASN1_SUCCESS) {
-		gnutls_assert();
-		return _gnutls_asn2err(result);
-	}
+    len = sizeof(version);
+    if ((result =
+	 asn1_read_value(crl->crl, "tbsCertList.version", version,
+			 &len)) != ASN1_SUCCESS) {
+	gnutls_assert();
+	return _gnutls_asn2err(result);
+    }
 
-	return (int) version[0] + 1;
+    return (int) version[0] + 1;
 }
 
 /**
@@ -329,13 +333,12 @@ int gnutls_x509_crl_get_version(gnutls_x509_crl crl)
   **/
 time_t gnutls_x509_crl_get_this_update(gnutls_x509_crl crl)
 {
-	if (crl == NULL) {
-		gnutls_assert();
-		return (time_t)-1;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return (time_t) - 1;
+    }
 
-	return _gnutls_x509_get_time(crl->crl,
-				     "tbsCertList.thisUpdate");
+    return _gnutls_x509_get_time(crl->crl, "tbsCertList.thisUpdate");
 }
 
 /**
@@ -351,13 +354,12 @@ time_t gnutls_x509_crl_get_this_update(gnutls_x509_crl crl)
   **/
 time_t gnutls_x509_crl_get_next_update(gnutls_x509_crl crl)
 {
-	if (crl == NULL) {
-		gnutls_assert();
-		return (time_t)-1;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return (time_t) - 1;
+    }
 
-	return _gnutls_x509_get_time(crl->crl,
-				     "tbsCertList.nextUpdate");
+    return _gnutls_x509_get_time(crl->crl, "tbsCertList.nextUpdate");
 }
 
 /**
@@ -373,24 +375,23 @@ time_t gnutls_x509_crl_get_next_update(gnutls_x509_crl crl)
 int gnutls_x509_crl_get_crt_count(gnutls_x509_crl crl)
 {
 
-	int count, result;
+    int count, result;
 
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	result =
-	    asn1_number_of_elements(crl->crl,
-				    "tbsCertList.revokedCertificates",
-				    &count);
+    result =
+	asn1_number_of_elements(crl->crl,
+				"tbsCertList.revokedCertificates", &count);
 
-	if (result != ASN1_SUCCESS) {
-		gnutls_assert();
-		return 0;	/* no certificates */
-	}
+    if (result != ASN1_SUCCESS) {
+	gnutls_assert();
+	return 0;		/* no certificates */
+    }
 
-	return count;
+    return count;
 }
 
 /**
@@ -398,7 +399,7 @@ int gnutls_x509_crl_get_crt_count(gnutls_x509_crl crl)
   * @crl: should contain a gnutls_x509_crl structure
   * @index: the index of the certificate to extract (starting from 0)
   * @serial: where the serial number will be copied
-  * @serial_size: initialy holds the size of serial
+  * @serial_size: initially holds the size of serial
   * @time: if non null, will hold the time this certificate was revoked
   *
   * This function will return the serial number of the specified, by the index, 
@@ -408,50 +409,47 @@ int gnutls_x509_crl_get_crt_count(gnutls_x509_crl crl)
   *
   **/
 int gnutls_x509_crl_get_crt_serial(gnutls_x509_crl crl, int index,
-				    unsigned char *serial,
-				    size_t *serial_size, time_t * time)
+				   unsigned char *serial,
+				   size_t * serial_size, time_t * time)
 {
 
-	int result, _serial_size;
-	char str_index[MAX_INT_DIGITS];
-	char serial_name[64];
-	char date_name[64];
+    int result, _serial_size;
+    char str_index[MAX_INT_DIGITS];
+    char serial_name[64];
+    char date_name[64];
 
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	_gnutls_int2str(index + 1, str_index);
-	_gnutls_str_cpy(serial_name, sizeof(serial_name),
-			"tbsCertList.revokedCertificates.?");
-	_gnutls_str_cat(serial_name, sizeof(serial_name), str_index);
-	_gnutls_str_cat(serial_name, sizeof(serial_name),
-			".userCertificate");
+    _gnutls_int2str(index + 1, str_index);
+    _gnutls_str_cpy(serial_name, sizeof(serial_name),
+		    "tbsCertList.revokedCertificates.?");
+    _gnutls_str_cat(serial_name, sizeof(serial_name), str_index);
+    _gnutls_str_cat(serial_name, sizeof(serial_name), ".userCertificate");
 
-	_gnutls_str_cpy(date_name, sizeof(date_name),
-			"tbsCertList.revokedCertificates.?");
-	_gnutls_str_cat(date_name, sizeof(date_name), str_index);
-	_gnutls_str_cat(date_name, sizeof(date_name), ".revocationDate");
+    _gnutls_str_cpy(date_name, sizeof(date_name),
+		    "tbsCertList.revokedCertificates.?");
+    _gnutls_str_cat(date_name, sizeof(date_name), str_index);
+    _gnutls_str_cat(date_name, sizeof(date_name), ".revocationDate");
 
-	_serial_size = *serial_size;
-	result =
-	     asn1_read_value(crl->crl, serial_name, serial,
-			     &_serial_size);
+    _serial_size = *serial_size;
+    result = asn1_read_value(crl->crl, serial_name, serial, &_serial_size);
 
-	*serial_size = _serial_size;
-	if (result != ASN1_SUCCESS) {
-		gnutls_assert();
-		if (result == ASN1_ELEMENT_NOT_FOUND)
-			return GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
-		return _gnutls_asn2err(result);
-	}
+    *serial_size = _serial_size;
+    if (result != ASN1_SUCCESS) {
+	gnutls_assert();
+	if (result == ASN1_ELEMENT_NOT_FOUND)
+	    return GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
+	return _gnutls_asn2err(result);
+    }
 
-	if (time) {
-		*time = _gnutls_x509_get_time(crl->crl, date_name);
-	}
+    if (time) {
+	*time = _gnutls_x509_get_time(crl->crl, date_name);
+    }
 
-	return 0;
+    return 0;
 }
 
 /*-
@@ -468,63 +466,65 @@ int gnutls_x509_crl_get_crt_serial(gnutls_x509_crl crl, int index,
 int _gnutls_x509_crl_get_raw_issuer_dn(gnutls_x509_crl crl,
 				       gnutls_datum * dn)
 {
-	ASN1_TYPE c2 = ASN1_TYPE_EMPTY;
-	int result, len1;
-	int start1, end1;
-	gnutls_datum crl_signed_data;
+    ASN1_TYPE c2 = ASN1_TYPE_EMPTY;
+    int result, len1;
+    int start1, end1;
+    gnutls_datum crl_signed_data;
 
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	/* get the issuer of 'crl'
-	 */
-	if ((result =
-	     asn1_create_element(_gnutls_get_pkix(), "PKIX1.TBSCertList",
-				 &c2)) != ASN1_SUCCESS) {
-		gnutls_assert();
-		return _gnutls_asn2err(result);
-	}
+    /* get the issuer of 'crl'
+     */
+    if ((result =
+	 asn1_create_element(_gnutls_get_pkix(), "PKIX1.TBSCertList",
+			     &c2)) != ASN1_SUCCESS) {
+	gnutls_assert();
+	return _gnutls_asn2err(result);
+    }
 
-	result = _gnutls_x509_get_signed_data( crl->crl, "tbsCertList", &crl_signed_data);
-	if (result < 0) {
-		gnutls_assert();
-		goto cleanup;
-	}
+    result =
+	_gnutls_x509_get_signed_data(crl->crl, "tbsCertList",
+				     &crl_signed_data);
+    if (result < 0) {
+	gnutls_assert();
+	goto cleanup;
+    }
 
-	result =
-	    asn1_der_decoding(&c2, crl_signed_data.data,
-			      crl_signed_data.size, NULL);
-	if (result != ASN1_SUCCESS) {
-		/* couldn't decode DER */
-		gnutls_assert();
-		asn1_delete_structure(&c2);
-		result = _gnutls_asn2err(result);
-		goto cleanup;
-	}
-
-	result =
-	    asn1_der_decoding_startEnd(c2, crl_signed_data.data,
-				       crl_signed_data.size, "issuer",
-				       &start1, &end1);
-
-	if (result != ASN1_SUCCESS) {
-		gnutls_assert();
-		result = _gnutls_asn2err(result);
-		goto cleanup;
-	}
-
-	len1 = end1 - start1 + 1;
-
-	_gnutls_set_datum( dn, &crl_signed_data.data[start1], len1);
-
-	result = 0;
-
-cleanup:
+    result =
+	asn1_der_decoding(&c2, crl_signed_data.data,
+			  crl_signed_data.size, NULL);
+    if (result != ASN1_SUCCESS) {
+	/* couldn't decode DER */
+	gnutls_assert();
 	asn1_delete_structure(&c2);
-	_gnutls_free_datum( &crl_signed_data);
-	return result;
+	result = _gnutls_asn2err(result);
+	goto cleanup;
+    }
+
+    result =
+	asn1_der_decoding_startEnd(c2, crl_signed_data.data,
+				   crl_signed_data.size, "issuer",
+				   &start1, &end1);
+
+    if (result != ASN1_SUCCESS) {
+	gnutls_assert();
+	result = _gnutls_asn2err(result);
+	goto cleanup;
+    }
+
+    len1 = end1 - start1 + 1;
+
+    _gnutls_set_datum(dn, &crl_signed_data.data[start1], len1);
+
+    result = 0;
+
+  cleanup:
+    asn1_delete_structure(&c2);
+    _gnutls_free_datum(&crl_signed_data);
+    return result;
 }
 
 /**
@@ -545,16 +545,18 @@ cleanup:
   * Returns 0 on success, and a negative value on failure.
   *
   **/
-int gnutls_x509_crl_export( gnutls_x509_crl crl,
-	gnutls_x509_crt_fmt format, void* output_data, size_t* output_data_size)
+int gnutls_x509_crl_export(gnutls_x509_crl crl,
+			   gnutls_x509_crt_fmt format, void *output_data,
+			   size_t * output_data_size)
 {
-	if (crl == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_INVALID_REQUEST;
-	}
+    if (crl == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_INVALID_REQUEST;
+    }
 
-	return _gnutls_x509_export_int( crl->crl, format, PEM_CRL, *output_data_size,
-		output_data, output_data_size);
+    return _gnutls_x509_export_int(crl->crl, format, PEM_CRL,
+				   *output_data_size, output_data,
+				   output_data_size);
 }
 
 /*-
@@ -569,42 +571,43 @@ int gnutls_x509_crl_export( gnutls_x509_crl crl,
   -*/
 int _gnutls_x509_crl_cpy(gnutls_x509_crl dest, gnutls_x509_crl src)
 {
-int ret;
-size_t der_size;
-opaque * der;
-gnutls_datum tmp;
+    int ret;
+    size_t der_size;
+    opaque *der;
+    gnutls_datum tmp;
 
-	ret = gnutls_x509_crl_export( src, GNUTLS_X509_FMT_DER, NULL, &der_size);
-	if (ret != GNUTLS_E_SHORT_MEMORY_BUFFER) {
-		gnutls_assert();
-		return ret;
-	}
+    ret =
+	gnutls_x509_crl_export(src, GNUTLS_X509_FMT_DER, NULL, &der_size);
+    if (ret != GNUTLS_E_SHORT_MEMORY_BUFFER) {
+	gnutls_assert();
+	return ret;
+    }
 
-	der = gnutls_alloca( der_size);
-	if (der == NULL) {
-		gnutls_assert();
-		return GNUTLS_E_MEMORY_ERROR;
-	}
+    der = gnutls_alloca(der_size);
+    if (der == NULL) {
+	gnutls_assert();
+	return GNUTLS_E_MEMORY_ERROR;
+    }
 
-	ret = gnutls_x509_crl_export( src, GNUTLS_X509_FMT_DER, der, &der_size);
-	if (ret < 0) {
-		gnutls_assert();
-		gnutls_afree( der);
-		return ret;
-	}
+    ret = gnutls_x509_crl_export(src, GNUTLS_X509_FMT_DER, der, &der_size);
+    if (ret < 0) {
+	gnutls_assert();
+	gnutls_afree(der);
+	return ret;
+    }
 
-	tmp.data = der;
-	tmp.size = der_size;
-	ret = gnutls_x509_crl_import( dest, &tmp, GNUTLS_X509_FMT_DER);
+    tmp.data = der;
+    tmp.size = der_size;
+    ret = gnutls_x509_crl_import(dest, &tmp, GNUTLS_X509_FMT_DER);
 
-	gnutls_afree( der);
+    gnutls_afree(der);
 
-	if (ret < 0) {
-		gnutls_assert();
-		return ret;
-	}
+    if (ret < 0) {
+	gnutls_assert();
+	return ret;
+    }
 
-	return 0;
+    return 0;
 
 }
 
